<?php

namespace Drupal\available_updates\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\update\UpdateManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\update\UpdateManagerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Class AvailableUpdatesController.
 */
class AvailableUpdatesController extends ControllerBase {

  /**
   * Drupal\update\UpdateManagerInterface definition.
   *
   * @var \Drupal\update\UpdateManagerInterface
   */
  protected $updateManager;

  /**
   * Constructs a new AvailableUpdatesController object.
   */
  public function __construct(UpdateManagerInterface $update_manager) {
    $this->updateManager = $update_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('update.manager')
    );
  }

  /**
   * Get the available updates.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Return available updates.
   */
  public function getAvailableUpdates() {

    if ($available = update_get_available(TRUE)) {
      $this->moduleHandler()->loadInclude('update', 'compare.inc');
    }

    $calculated_updates = update_calculate_project_data($available);

    foreach ($calculated_updates as $project_name => $project_details) {
      if ($project_details['status'] == UpdateManager::CURRENT) {
        unset($calculated_updates[$project_name]);
      }
    }

    return new JsonResponse([
      $this->config('system.site')->get('name') => $calculated_updates,
    ]);
  }

}
